@@ -1,15 +1,15 @@
 #ifndef FILEZILLA_ENGINEPRIVATE_HEADER
 #define FILEZILLA_ENGINEPRIVATE_HEADER
 
+#include "../include/engine_context.h"
+#include "../include/FileZillaEngine.h"
+#include "../include/optionsbase.h"
+
 #include <libfilezilla/event.hpp>
 #include <libfilezilla/event_handler.hpp>
 #include <libfilezilla/mutex.hpp>
 #include <libfilezilla/time.hpp>
 
-#include "engine_context.h"
-#include "FileZillaEngine.h"
-#include "option_change_event_handler.h"
-
 #include <atomic>
 #include <list>
 #include <deque>
@@ -54,10 +54,10 @@ protected:
 	CFileZillaEnginePrivate& engine_;
 };
 
-class CFileZillaEnginePrivate final : public fz::event_handler, COptionChangeEventHandler
+class CFileZillaEnginePrivate final : public fz::event_handler
 {
 public:
-	CFileZillaEnginePrivate(CFileZillaEngineContext& engine_context, CFileZillaEngine& parent, EngineNotificationHandler& notificationHandler);
+	CFileZillaEnginePrivate(CFileZillaEngineContext& engine_context, CFileZillaEngine& parent, std::function<void(CFileZillaEngine*)> const& notification_cb);
 	virtual ~CFileZillaEnginePrivate();
 
 	int Execute(CCommand const& command);
@@ -79,12 +79,12 @@ public:
 	void SetActive(int direction);
 
 	// Add new pending notification
-	void AddNotification(fz::scoped_lock& lock, CNotification *pNotification); // note: Unlocks the mutex!
-	void AddNotification(CNotification *pNotification);
-	void AddLogNotification(CLogmsgNotification *pNotification);
+	void AddNotification(fz::scoped_lock& lock, std::unique_ptr<CNotification> && notification); // note: Unlocks the mutex!
+	void AddNotification(std::unique_ptr<CNotification> && notification);
+	void AddLogNotification(std::unique_ptr<CLogmsgNotification> && notification);
 	std::unique_ptr<CNotification> GetNextNotification();
 
-	COptionsBase& GetOptions() { return m_options; }
+	COptionsBase& GetOptions() { return options_; }
 	fz::rate_limiter& GetRateLimiter() { return rate_limiter_; }
 	CDirectoryCache& GetDirectoryCache() { return directory_cache_; }
 	CPathCache& GetPathCache() { return path_cache_; }
@@ -112,7 +112,7 @@ public:
 	fz::logger_interface& GetLogger();
 
 protected:
-	virtual void OnOptionsChanged(changed_options_t const& options);
+	void OnOptionsChanged(watched_options const& options);
 
 	void SendQueuedLogs(bool reset_flag = false);
 	void ClearQueuedLogs(bool reset_flag);
@@ -156,7 +156,7 @@ protected:
 	// Used to synchronize access to the notification list
 	fz::mutex notification_mutex_{false};
 
-	EngineNotificationHandler& notification_handler_;
+	std::function<void(CFileZillaEngine*)> const notification_cb_;
 
 	unsigned int const m_engine_id;
 
@@ -178,7 +178,7 @@ protected:
 
 	std::atomic<unsigned int> asyncRequestCounter_{};
 
-	COptionsBase& m_options;
+	COptionsBase& options_;
 
 	std::unique_ptr<CLogging> logger_;
 
