@@ -1,27 +1,30 @@
-#include <filezilla.h>
+#include "../filezilla.h"
 
 #include "cwd.h"
 #include "chmod.h"
 #include "delete.h"
-#include "../directorycache.h"
-#include "directorylistingparser.h"
-#include "engineprivate.h"
-#include "externalipresolver.h"
 #include "filetransfer.h"
 #include "ftpcontrolsocket.h"
-#include "iothread.h"
 #include "list.h"
 #include "logon.h"
 #include "mkd.h"
-#include "pathcache.h"
-#include "proxy.h"
 #include "rawcommand.h"
 #include "rawtransfer.h"
 #include "rename.h"
 #include "rmd.h"
-#include "servercapabilities.h"
 #include "transfersocket.h"
 
+#include "../directorycache.h"
+#include "../directorylistingparser.h"
+#include "../engineprivate.h"
+#include "../iothread.h"
+#include "../pathcache.h"
+#include "../proxy.h"
+#include "../servercapabilities.h"
+
+#include "../../include/externalipresolver.h"
+#include "../../include/engine_options.h"
+
 #include <libfilezilla/file.hpp>
 #include <libfilezilla/iputils.hpp>
 #include <libfilezilla/local_filesys.hpp>
@@ -343,7 +346,7 @@ int CFtpControlSocket::ResetOperation(int nErrorCode)
 				}
 			}
 		}
-		if (nErrorCode != FZ_REPLY_OK && data.download_ && !data.fileDidExist_) {
+		if (nErrorCode != FZ_REPLY_OK && data.download() && !data.fileDidExist_) {
 			data.ioThread_.reset();
 			int64_t size;
 			bool isLink;
@@ -404,7 +407,7 @@ void CFtpControlSocket::ChangeDir(CServerPath const& path, std::wstring const& s
 	pData->link_discovery_ = link_discovery;
 
 	if (!operations_.empty() && operations_.back()->opId == Command::transfer &&
-		!static_cast<CFtpFileTransferOpData &>(*operations_.back()).download_)
+		!static_cast<CFtpFileTransferOpData &>(*operations_.back()).download())
 	{
 		pData->tryMkdOnFail_ = true;
 		assert(subDir.empty());
@@ -414,12 +417,11 @@ void CFtpControlSocket::ChangeDir(CServerPath const& path, std::wstring const& s
 }
 
 void CFtpControlSocket::FileTransfer(std::wstring const& localFile, CServerPath const& remotePath,
-									std::wstring const& remoteFile, bool download,
-									CFileTransferCommand::t_transferSettings const& transferSettings)
+									std::wstring const& remoteFile, transfer_flags const& flags)
 {
 	log(logmsg::debug_verbose, L"CFtpControlSocket::FileTransfer()");
 
-	auto pData = std::make_unique<CFtpFileTransferOpData>(*this, download, localFile, remoteFile, remotePath, transferSettings);
+	auto pData = std::make_unique<CFtpFileTransferOpData>(*this, localFile, remoteFile, remotePath, flags);
 	Push(std::move(pData));
 }
 
@@ -594,17 +596,17 @@ int CFtpControlSocket::GetExternalIPAddress(std::string& address)
 	// Local IP should work. Only a complete moron would use IPv6
 	// and NAT at the same time.
 	if (socket_->address_family() != fz::address_type::ipv6) {
-		int mode = engine_.GetOptions().GetOptionVal(OPTION_EXTERNALIPMODE);
+		int mode = engine_.GetOptions().get_int(OPTION_EXTERNALIPMODE);
 
 		if (mode) {
-			if (engine_.GetOptions().GetOptionVal(OPTION_NOEXTERNALONLOCAL) &&
+			if (engine_.GetOptions().get_int(OPTION_NOEXTERNALONLOCAL) &&
 				!fz::is_routable_address(socket_->peer_ip()))
 				// Skip next block, use local address
 				goto getLocalIP;
 		}
 
 		if (mode == 1) {
-			std::wstring ip = engine_.GetOptions().GetOption(OPTION_EXTERNALIP);
+			std::wstring ip = engine_.GetOptions().get_string(OPTION_EXTERNALIP);
 			if (!ip.empty()) {
 				address = fz::to_string(ip);
 				return FZ_REPLY_OK;
@@ -616,14 +618,14 @@ int CFtpControlSocket::GetExternalIPAddress(std::string& address)
 			if (!m_pIPResolver) {
 				std::string localAddress = socket_->local_ip(true);
 
-				if (!localAddress.empty() && localAddress == fz::to_string(engine_.GetOptions().GetOption(OPTION_LASTRESOLVEDIP))) {
+				if (!localAddress.empty() && localAddress == fz::to_string(engine_.GetOptions().get_string(OPTION_LASTRESOLVEDIP))) {
 					log(logmsg::debug_verbose, L"Using cached external IP address");
 
 					address = localAddress;
 					return FZ_REPLY_OK;
 				}
 
-				std::wstring resolverAddress = engine_.GetOptions().GetOption(OPTION_EXTERNALIPRESOLVER);
+				std::wstring resolverAddress = engine_.GetOptions().get_string(OPTION_EXTERNALIPRESOLVER);
 
 				log(logmsg::debug_info, _("Retrieving external IP address from %s"), resolverAddress);
 
@@ -643,7 +645,7 @@ int CFtpControlSocket::GetExternalIPAddress(std::string& address)
 				log(logmsg::debug_info, L"Got external IP address");
 				address = m_pIPResolver->GetIP();
 
-				engine_.GetOptions().SetOption(OPTION_LASTRESOLVEDIP, fz::to_wstring(address));
+				engine_.GetOptions().set(OPTION_LASTRESOLVEDIP, fz::to_wstring(address));
 
 				m_pIPResolver.reset();
 
@@ -745,7 +747,7 @@ void CFtpControlSocket::OnTimer(fz::timer_id id)
 
 void CFtpControlSocket::StartKeepaliveTimer()
 {
-	if (!engine_.GetOptions().GetOptionVal(OPTION_FTP_SENDKEEPALIVE)) {
+	if (!engine_.GetOptions().get_int(OPTION_FTP_SENDKEEPALIVE)) {
 		return;
 	}
 
@@ -793,6 +795,10 @@ void CFtpControlSocket::ResetSocket()
 	tls_layer_.reset();
 	m_pendingReplies = 0;
 	m_repliesToSkip = 0;
+	m_Response.clear();
+	m_MultilineResponseCode.clear();;
+	m_MultilineResponseLines.clear();
+
 	CRealControlSocket::ResetSocket();
 }
 
@@ -802,7 +808,7 @@ void CFtpControlSocket::OnVerifyCert(fz::tls_layer* source, fz::tls_session_info
 		return;
 	}
 
-	SendAsyncRequest(new CCertificateNotification(std::move(info)));
+	SendAsyncRequest(std::make_unique<CCertificateNotification>(std::move(info)));
 }
 
 void CFtpControlSocket::Push(std::unique_ptr<COpData> && pNewOpData)
