@@ -3,15 +3,15 @@
 
 #include "httpcontrolsocket.h"
 
+#include <libfilezilla/file.hpp>
+
 class CServerPath;
 
 class CHttpFileTransferOpData final : public CFileTransferOpData, public CHttpOpData
 {
 public:
-	CHttpFileTransferOpData(CHttpControlSocket & controlSocket, bool is_download, std::wstring const& local_file, std::wstring const& remote_file, CServerPath const& remote_path, CFileTransferCommand::t_transferSettings const& settings)
-		: CFileTransferOpData(L"CHttpFileTransferOpData", is_download, local_file, remote_file, remote_path, settings)
-		, CHttpOpData(controlSocket)
-	{}
+	CHttpFileTransferOpData(CHttpControlSocket & controlSocket, std::wstring const& local_file, std::wstring const& remote_file, CServerPath const& remote_path, transfer_flags const& flags);
+	CHttpFileTransferOpData(CHttpControlSocket & controlSocket, fz::uri const& uri, std::string const& verb, std::string const& body);
 
 	virtual int Send() override;
 	virtual int ParseResponse() override { return FZ_REPLY_INTERNALERROR; }
