@@ -1,13 +1,14 @@
-#include <filezilla.h>
+#include "../filezilla.h"
 
 #include "connect.h"
-#include "controlsocket.h"
-#include "engineprivate.h"
 #include "filetransfer.h"
 #include "httpcontrolsocket.h"
 #include "internalconnect.h"
 #include "request.h"
 
+#include "../controlsocket.h"
+#include "../engineprivate.h"
+
 #include <libfilezilla/file.hpp>
 #include <libfilezilla/iputils.hpp>
 #include <libfilezilla/local_filesys.hpp>
@@ -278,16 +279,15 @@ void CHttpControlSocket::OnConnect()
 }
 
 void CHttpControlSocket::FileTransfer(std::wstring const& localFile, CServerPath const& remotePath,
-									std::wstring const& remoteFile, bool download,
-									CFileTransferCommand::t_transferSettings const& settings)
+									std::wstring const& remoteFile, transfer_flags const& flags)
 {
 	log(logmsg::debug_verbose, L"CHttpControlSocket::FileTransfer()");
 
-	if (download) {
+	if (flags & transfer_flags::download) {
 		log(logmsg::status, _("Downloading %s"), remotePath.FormatFilename(remoteFile));
 	}
 
-	Push(std::make_unique<CHttpFileTransferOpData>(*this, download, localFile, remoteFile, remotePath, settings));
+	Push(std::make_unique<CHttpFileTransferOpData>(*this, localFile, remoteFile, remotePath, flags));
 }
 
 void CHttpControlSocket::FileTransfer(CHttpRequestCommand const& command)
