@@ -1,8 +1,9 @@
 #ifndef FILEZILLA_ENGINE_HTTP_HTTPCONTROLSOCKET_HEADER
 #define FILEZILLA_ENGINE_HTTP_HTTPCONTROLSOCKET_HEADER
 
-#include "controlsocket.h"
-#include "httpheaders.h"
+#include "../controlsocket.h"
+
+#include "../../include/httpheaders.h"
 
 #include <libfilezilla/file.hpp>
 #include <libfilezilla/uri.hpp>
@@ -250,8 +251,7 @@ public:
 protected:
 	virtual void Connect(CServer const& server, Credentials const& credentials) override;
 	virtual void FileTransfer(std::wstring const& localFile, CServerPath const& remotePath,
-		std::wstring const& remoteFile, bool download,
-		CFileTransferCommand::t_transferSettings const& transferSettings) override;
+		std::wstring const& remoteFile, transfer_flags const& flags) override;
 
 	void Request(std::shared_ptr<HttpRequestResponseInterface> const& request);
 	void Request(std::deque<std::shared_ptr<HttpRequestResponseInterface>> && requests);
