@@ -6,8 +6,8 @@
 class CStorjFileTransferOpData final : public CFileTransferOpData, public CStorjOpData
 {
 public:
-	CStorjFileTransferOpData(CStorjControlSocket & controlSocket, bool is_download, std::wstring const& local_file, std::wstring const& remote_file, CServerPath const& remote_path, CFileTransferCommand::t_transferSettings const& settings)
-		: CFileTransferOpData(L"CStorjFileTransferOpData", is_download, local_file, remote_file, remote_path, settings)
+	CStorjFileTransferOpData(CStorjControlSocket & controlSocket, std::wstring const& local_file, std::wstring const& remote_file, CServerPath const& remote_path, transfer_flags const& flags)
+		: CFileTransferOpData(L"CStorjFileTransferOpData", local_file, remote_file, remote_path, flags)
 		, CStorjOpData(controlSocket)
 	{
 	}
