@@ -26,7 +26,11 @@ enum class Command
 	httprequest, // Only used by HTTP protocol
 
 	// Only used internally
+	sleep,
+	lookup,
 	cwd,
+	common_private1, // Internal commands common to multiple protocols
+	common_private2,
 	private1,
 	private2,
 	private3,
@@ -47,7 +51,7 @@ enum class Command
 #define FZ_REPLY_NOTCONNECTED	(0x0020 | FZ_REPLY_ERROR)
 #define FZ_REPLY_DISCONNECTED	(0x0040)
 #define FZ_REPLY_INTERNALERROR	(0x0080 | FZ_REPLY_ERROR) // If you get this reply, the error description will be
-														  // given by the last Debug_Warning log message. This
+														  // given by the last debug_warning log message. This
 														  // should not happen unless there is a bug in FileZilla 3.
 #define FZ_REPLY_BUSY			(0x0100 | FZ_REPLY_ERROR)
 #define FZ_REPLY_ALREADYCONNECTED	(0x0200 | FZ_REPLY_ERROR) // Will be returned by connect if already connected
@@ -58,12 +62,13 @@ enum class Command
 #define FZ_REPLY_LINKNOTDIR		(0x4000 | FZ_REPLY_ERROR)
 
 #define FZ_REPLY_CONTINUE 0x8000 // Used internally
+#define FZ_REPLY_ERROR_NOTFOUND (0x10000 | FZ_REPLY_ERROR) // Used internally
 
 // --------------- //
 // Actual commands //
 // --------------- //
 
-class CCommand
+class FZC_PUBLIC_SYMBOL CCommand
 {
 public:
 	CCommand() = default;
@@ -80,7 +85,7 @@ protected:
 };
 
 template<typename Derived, Command id>
-class CCommandHelper : public CCommand
+class FZC_PUBLIC_SYMBOL CCommandHelper : public CCommand
 {
 public:
 	virtual Command GetId() const final { return id; }
@@ -96,11 +101,11 @@ protected:
 };
 
 template<Command id>
-class CBasicCommand final : public CCommandHelper<CBasicCommand<id>, id>
+class FZC_PUBLIC_SYMBOL CBasicCommand final : public CCommandHelper<CBasicCommand<id>, id>
 {
 };
 
-class CConnectCommand final : public CCommandHelper<CConnectCommand, Command::connect>
+class FZC_PUBLIC_SYMBOL CConnectCommand final : public CCommandHelper<CConnectCommand, Command::connect>
 {
 public:
 	explicit CConnectCommand(CServer const& server, ServerHandle const& handle, Credentials const& credentials, bool retry_conncting = true);
@@ -125,7 +130,7 @@ typedef CBasicCommand<Command::disconnect> CDisconnectCommand;
 #define LIST_FLAG_FALLBACK_CURRENT 4
 #define LIST_FLAG_LINK 8
 #define LIST_FLAG_CLEARCACHE 16
-class CListCommand final : public CCommandHelper<CListCommand, Command::list>
+class FZC_PUBLIC_SYMBOL CListCommand final : public CCommandHelper<CListCommand, Command::list>
 {
 	// Without a given directory, the current directory will be listed.
 	// Directories can either be given as absolute path or as
@@ -161,37 +166,81 @@ protected:
 	int const m_flags;
 };
 
-class CFileTransferCommand final : public CCommandHelper<CFileTransferCommand, Command::transfer>
+enum class transfer_flags : unsigned short
+{
+	none = 0,
+
+	interface_reserved_mask = 0x08u, // The engine will never touch these
+	
+	download = 0x10,
+	fsync = 0x20,
+
+	// Free bits in the middle
+
+	protocol_reserved_mask = 0xfe00,
+	protocol_reserved_max = 0x8000
+};
+
+inline bool operator&(transfer_flags lhs, transfer_flags rhs)
+{
+	return (static_cast<std::underlying_type_t<transfer_flags>>(lhs) & static_cast<std::underlying_type_t<transfer_flags>>(rhs)) != 0;
+}
+
+inline transfer_flags operator|(transfer_flags lhs, transfer_flags rhs)
+{
+	return static_cast<transfer_flags>(static_cast<std::underlying_type_t<transfer_flags>>(lhs) | static_cast<std::underlying_type_t<transfer_flags>>(rhs));
+}
+
+inline transfer_flags& operator|=(transfer_flags& lhs, transfer_flags rhs)
+{
+	lhs = static_cast<transfer_flags>(static_cast<std::underlying_type_t<transfer_flags>>(lhs) | static_cast<std::underlying_type_t<transfer_flags>>(rhs));
+	return lhs;
+}
+
+inline transfer_flags operator-(transfer_flags lhs, transfer_flags rhs)
+{
+	return static_cast<transfer_flags>(static_cast<std::underlying_type_t<transfer_flags>>(lhs) & ~static_cast<std::underlying_type_t<transfer_flags>>(rhs));
+}
+
+inline transfer_flags& operator-=(transfer_flags& lhs, transfer_flags rhs)
+{
+	lhs = static_cast<transfer_flags>(static_cast<std::underlying_type_t<transfer_flags>>(lhs) & ~static_cast<std::underlying_type_t<transfer_flags>>(rhs));
+	return lhs;
+}
+
+inline bool operator!(transfer_flags flags)
+{
+	return static_cast<std::underlying_type_t<transfer_flags>>(flags) == 0;
+}
+
+namespace ftp_transfer_flags
+{
+	auto constexpr ascii = transfer_flags::protocol_reserved_max;
+}
+
+class FZC_PUBLIC_SYMBOL CFileTransferCommand final : public CCommandHelper<CFileTransferCommand, Command::transfer>
 {
 public:
-	class t_transferSettings final
-	{
-	public:
-		bool binary{true};
-		bool fsync{};
-	};
-
 	// For uploads, set download to false.
 	// For downloads, localFile can be left empty if supported by protocol.
 	// Check for nId_data notification.
 	// FIXME: localFile empty iff protocol is HTTP.
-	CFileTransferCommand(std::wstring const& localFile, CServerPath const& remotePath, std::wstring const& remoteFile, bool download, t_transferSettings const& m_transferSettings);
+	CFileTransferCommand(std::wstring const& localFile, CServerPath const& remotePath, std::wstring const& remoteFile, transfer_flags const& flags);
 
 	std::wstring GetLocalFile() const;
 	CServerPath GetRemotePath() const;
 	std::wstring GetRemoteFile() const;
-	bool Download() const;
-	const t_transferSettings& GetTransferSettings() const { return m_transferSettings; }
+	bool Download() const { return flags_ & transfer_flags::download; }
+	transfer_flags const& GetFlags() const { return flags_; }
 
 protected:
 	std::wstring const m_localFile;
 	CServerPath const m_remotePath;
 	std::wstring const m_remoteFile;
-	bool const m_download;
-	t_transferSettings const m_transferSettings;
+	transfer_flags const flags_;
 };
 
-class CHttpRequestCommand final : public CCommandHelper<CHttpRequestCommand, Command::httprequest>
+class FZC_PUBLIC_SYMBOL CHttpRequestCommand final : public CCommandHelper<CHttpRequestCommand, Command::httprequest>
 {
 public:
 	// Reply body is delivered through nId_data notifications
@@ -206,7 +255,7 @@ public:
 	std::string const body_;
 };
 
-class CRawCommand final : public CCommandHelper<CRawCommand, Command::raw>
+class FZC_PUBLIC_SYMBOL CRawCommand final : public CCommandHelper<CRawCommand, Command::raw>
 {
 public:
 	explicit CRawCommand(std::wstring const& command);
@@ -219,22 +268,22 @@ protected:
 	std::wstring m_command;
 };
 
-class CDeleteCommand final : public CCommandHelper<CDeleteCommand, Command::del>
+class FZC_PUBLIC_SYMBOL CDeleteCommand final : public CCommandHelper<CDeleteCommand, Command::del>
 {
 public:
-	CDeleteCommand(CServerPath const& path, std::deque<std::wstring> && files);
+	CDeleteCommand(CServerPath const& path, std::vector<std::wstring> && files);
 
 	CServerPath GetPath() const { return m_path; }
-	const std::deque<std::wstring>& GetFiles() const { return m_files; }
-	std::deque<std::wstring>&& ExtractFiles() { return std::move(m_files); }
+	const std::vector<std::wstring>& GetFiles() const { return files_; }
+	std::vector<std::wstring>&& ExtractFiles() { return std::move(files_); }
 
 	bool valid() const { return !GetPath().empty() && !GetFiles().empty(); }
 protected:
 	CServerPath const m_path;
-	std::deque<std::wstring> m_files;
+	std::vector<std::wstring> files_;
 };
 
-class CRemoveDirCommand final : public CCommandHelper<CRemoveDirCommand, Command::removedir>
+class FZC_PUBLIC_SYMBOL CRemoveDirCommand final : public CCommandHelper<CRemoveDirCommand, Command::removedir>
 {
 public:
 	// Directories can either be given as absolute path or as
@@ -251,7 +300,7 @@ protected:
 	std::wstring const m_subDir;
 };
 
-class CMkdirCommand final : public CCommandHelper<CMkdirCommand, Command::mkdir>
+class FZC_PUBLIC_SYMBOL CMkdirCommand final : public CCommandHelper<CMkdirCommand, Command::mkdir>
 {
 public:
 	explicit CMkdirCommand(CServerPath const& path);
@@ -264,7 +313,7 @@ protected:
 	CServerPath const m_path;
 };
 
-class CRenameCommand final : public CCommandHelper<CRenameCommand, Command::rename>
+class FZC_PUBLIC_SYMBOL CRenameCommand final : public CCommandHelper<CRenameCommand, Command::rename>
 {
 public:
 	CRenameCommand(CServerPath const& fromPath, std::wstring const& fromFile,
@@ -284,11 +333,11 @@ protected:
 	std::wstring const m_toFile;
 };
 
-class CChmodCommand final : public CCommandHelper<CChmodCommand, Command::chmod>
+class FZC_PUBLIC_SYMBOL CChmodCommand final : public CCommandHelper<CChmodCommand, Command::chmod>
 {
 public:
 	// The permission string should be given in a format understandable by the server.
-	// Most likely it's the defaut octal representation used by the unix chmod command,
+	// Most likely it's the default octal representation used by the unix chmod command,
 	// i.e. chmod 755 foo.bar
 	CChmodCommand(CServerPath const& path, std::wstring const& file, std::wstring const& permission);
 
