@@ -2,14 +2,13 @@
 #define FILEZILLA_INTERFACE_QUEUEVIEW_HEADER
 
 #include "dndobjects.h"
-#include "queue.h"
-
-#include <libfilezilla_engine.h>
-#include <option_change_event_handler.h>
-
-#include "queue_storage.h"
 #include "local_recursive_operation.h"
-#include "notification.h"
+#include "option_change_event_handler.h"
+#include "queue.h"
+#include "queue_storage.h"
+
+#include "../include/libfilezilla_engine.h"
+#include "../include/notification.h"
 
 #include <wx/progdlg.h>
 
@@ -107,7 +106,7 @@ private:
 	bool trigger_{};
 };
 
-class CQueueView final : public CQueueViewBase, public COptionChangeEventHandler, public CGlobalStateEventHandler, private EngineNotificationHandler
+class CQueueView final : public CQueueViewBase, public COptionChangeEventHandler, public CGlobalStateEventHandler
 {
 	friend class CQueueViewDropTarget;
 	friend class CQueueViewFailed;
@@ -169,7 +168,7 @@ protected:
 	WXLRESULT MSWWindowProc(WXUINT nMsg, WXWPARAM wParam, WXLPARAM lParam);
 #endif
 
-	virtual void OnOptionsChanged(changed_options_t const& options) override;
+	virtual void OnOptionsChanged(watched_options const& options) override;
 
 	void AdvanceQueue(bool refresh = true);
 	bool TryStartNextTransfer();
@@ -287,8 +286,7 @@ protected:
 	// Unit is byte/s.
 	wxFileOffset GetCurrentSpeed(bool countDownload, bool countUpload);
 
-	virtual void OnEngineEvent(CFileZillaEngine* engine) override;
-	void DoOnEngineEvent(CFileZillaEngine* engine);
+	void OnEngineEvent(CFileZillaEngine* engine);
 
 	void OnAskPassword();
 
