@@ -1302,7 +1302,7 @@ void CRemoteListView::TransferSelectedFiles(const CLocalPath& local_parent, bool
 	if (!root.empty()) {
 		pRecursiveOperation->AddRecursionRoot(std::move(root));
 		CFilterManager filter;
-		pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_transfer, filter.GetActiveFilters(), m_pDirectoryListing->path, !queue_only);
+		pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_transfer, filter.GetActiveFilters(), !queue_only);
 	}
 }
 
@@ -1533,9 +1533,7 @@ void CRemoteListView::OnMenuDelete(wxCommandEvent&)
 
 		if (!root.empty()) {
 			pRecursiveOperation->AddRecursionRoot(std::move(root));
-
-			pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_delete,
-														 filter.GetActiveFilters(), m_pDirectoryListing->path);
+			pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_delete, filter.GetActiveFilters());
 		}
 	}
 }
@@ -1846,8 +1844,7 @@ void CRemoteListView::HandleGenericChmod(ChmodUICommand &command)
 		pRecursiveOperation->SetChmodData(std::move(chmodData));
 		pRecursiveOperation->AddRecursionRoot(std::move(root));
 		CFilterManager filter;
-		pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_chmod,
-													 filter.GetActiveFilters(), m_pDirectoryListing->path);
+		pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_chmod, filter.GetActiveFilters());
 
 		// Refresh listing. This gets done implicitely by the recursive operation, so
 		// only it if not recursing.
@@ -2432,7 +2429,7 @@ void CRemoteListView::StartComparison()
 	}
 }
 
-bool CRemoteListView::get_next_file(std::wstring_view & name, std::wstring & path, bool& dir, int64_t& size, fz::datetime& date)
+bool CRemoteListView::get_next_file(std::wstring_view & name, std::wstring &, bool& dir, int64_t& size, fz::datetime& date)
 {
 	if (++m_comparisonIndex >= (int)m_originalIndexMapping.size()) {
 		return false;
@@ -2566,7 +2563,7 @@ wxString CRemoteListView::GetItemText(int item, unsigned int column)
 std::unique_ptr<CFileListCtrlSortBase> CRemoteListView::GetSortComparisonObject()
 {
 	CFileListCtrlSort<CDirectoryListing>::DirSortMode dirSortMode = GetDirSortMode();
-	CFileListCtrlSort<CDirectoryListing>::NameSortMode nameSortMode = GetNameSortMode();
+	NameSortMode nameSortMode = GetNameSortMode();
 
 	CDirectoryListing const& directoryListing = *m_pDirectoryListing;
 	if (!m_sortDirection) {
@@ -2809,6 +2806,6 @@ void CRemoteListView::OnMenuNewfile(wxCommandEvent&)
 		return;
 	}
 
-	CFileTransferCommand *cmd = new CFileTransferCommand(emptyfile, m_pDirectoryListing->path, newFileName, false, CFileTransferCommand::t_transferSettings());
+	CFileTransferCommand *cmd = new CFileTransferCommand(emptyfile, m_pDirectoryListing->path, newFileName, transfer_flags());
 	m_state.m_pCommandQueue->ProcessCommand(cmd);
 }
