@@ -30,8 +30,8 @@
 
 #include <array>
 
-DECLARE_EVENT_TYPE(fzEVT_TAB_CLOSING_DEFERRED, -1)
-DEFINE_EVENT_TYPE(fzEVT_TAB_CLOSING_DEFERRED)
+wxDECLARE_EVENT(fzEVT_TAB_CLOSING_DEFERRED, wxCommandEvent);
+wxDEFINE_EVENT(fzEVT_TAB_CLOSING_DEFERRED, wxCommandEvent);
 
 BEGIN_EVENT_TABLE(CContextControl, wxSplitterWindow)
 EVT_MENU(XRCID("ID_TABCONTEXT_REFRESH"), CContextControl::OnTabRefresh)
