@@ -19,11 +19,11 @@
 #endif
 
 #ifndef __WXMSW__
-DECLARE_EVENT_TYPE(fz_EVT_FILELIST_FOCUSCHANGE, -1)
-DECLARE_EVENT_TYPE(fz_EVT_DEFERRED_MOUSEEVENT, -1)
+wxDECLARE_EVENT(fz_EVT_FILELIST_FOCUSCHANGE, wxCommandEvent);
+wxDECLARE_EVENT(fz_EVT_DEFERRED_MOUSEEVENT, wxCommandEvent);
 #ifndef FILELISTCTRL_INCLUDE_TEMPLATE_DEFINITION
-DEFINE_EVENT_TYPE(fz_EVT_FILELIST_FOCUSCHANGE)
-DEFINE_EVENT_TYPE(fz_EVT_DEFERRED_MOUSEEVENT)
+wxDEFINE_EVENT(fz_EVT_FILELIST_FOCUSCHANGE, wxCommandEvent);
+wxDEFINE_EVENT(fz_EVT_DEFERRED_MOUSEEVENT, wxCommandEvent);
 #endif
 #endif
 
@@ -444,22 +444,22 @@ template<class CFileData> CFileListCtrlSortBase::DirSortMode CFileListCtrl<CFile
 	return dirSortMode;
 }
 
-template<class CFileData> CFileListCtrlSortBase::NameSortMode CFileListCtrl<CFileData>::GetNameSortMode()
+template<class CFileData> NameSortMode CFileListCtrl<CFileData>::GetNameSortMode()
 {
 	const int nameSortOption = COptions::Get()->get_int(OPTION_FILELIST_NAMESORT);
 
-	CFileListCtrlSortBase::NameSortMode nameSortMode;
+	NameSortMode nameSortMode;
 	switch (nameSortOption)
 	{
 	case 0:
 	default:
-		nameSortMode = CFileListCtrlSortBase::namesort_caseinsensitive;
+		nameSortMode = NameSortMode::case_insensitive;
 		break;
 	case 1:
-		nameSortMode = CFileListCtrlSortBase::namesort_casesensitive;
+		nameSortMode = NameSortMode::case_sensitive;
 		break;
 	case 2:
-		nameSortMode = CFileListCtrlSortBase::namesort_natural;
+		nameSortMode = NameSortMode::natural;
 		break;
 	}
 
