@@ -41,19 +41,19 @@ public:
 };
 
 template<>
-inline int DoCmpName(CRemoteSearchFileData const& data1, CRemoteSearchFileData const& data2, CFileListCtrlSortBase::NameSortMode const nameSortMode)
+inline int DoCmpName(CRemoteSearchFileData const& data1, CRemoteSearchFileData const& data2, NameSortMode const nameSortMode)
 {
 	int res;
 	switch (nameSortMode)
 	{
-	case CFileListCtrlSortBase::namesort_casesensitive:
+	case NameSortMode::case_sensitive:
 		res = CFileListCtrlSortBase::CmpCase(data1.name, data2.name);
 		break;
 	default:
-	case CFileListCtrlSortBase::namesort_caseinsensitive:
+	case NameSortMode::case_insensitive:
 		res = CFileListCtrlSortBase::CmpNoCase(data1.name, data2.name);
 		break;
-	case CFileListCtrlSortBase::namesort_natural:
+	case NameSortMode::natural:
 		res = CFileListCtrlSortBase::CmpNatural(data1.name, data2.name);
 		break;
 	}
@@ -71,19 +71,19 @@ inline int DoCmpName(CRemoteSearchFileData const& data1, CRemoteSearchFileData c
 }
 
 template<>
-inline int DoCmpName(CLocalSearchFileData const& data1, CLocalSearchFileData const& data2, CFileListCtrlSortBase::NameSortMode const nameSortMode)
+inline int DoCmpName(CLocalSearchFileData const& data1, CLocalSearchFileData const& data2, NameSortMode const nameSortMode)
 {
 	int res;
 	switch (nameSortMode)
 	{
-	case CFileListCtrlSortBase::namesort_casesensitive:
+	case NameSortMode::case_sensitive:
 		res = CFileListCtrlSortBase::CmpCase(data1.name, data2.name);
 		break;
 	default:
-	case CFileListCtrlSortBase::namesort_caseinsensitive:
+	case NameSortMode::case_insensitive:
 		res = CFileListCtrlSortBase::CmpNoCase(data1.name, data2.name);
 		break;
-	case CFileListCtrlSortBase::namesort_natural:
+	case NameSortMode::natural:
 		res = CFileListCtrlSortBase::CmpNatural(data1.name, data2.name);
 		break;
 	}
@@ -226,7 +226,7 @@ int64_t CSearchDialogFileList::ItemGetSize(int index) const
 std::unique_ptr<CFileListCtrlSortBase> CSearchDialogFileList::GetSortComparisonObject()
 {
 	CFileListCtrlSortBase::DirSortMode dirSortMode = GetDirSortMode();
-	CFileListCtrlSortBase::NameSortMode nameSortMode = GetNameSortMode();
+	NameSortMode nameSortMode = GetNameSortMode();
 
 	if (mode_ == CSearchDialog::search_mode::local) {
 		if (!m_sortDirection) {
@@ -789,8 +789,6 @@ bool CSearchDialog::Load()
 
 void CSearchDialog::Run()
 {
-	m_original_dir = m_state.GetRemotePath();
-
 	m_state.RegisterHandler(this, STATECHANGE_REMOTE_DIR_OTHER, m_state.GetRemoteRecursiveOperation());
 	m_state.RegisterHandler(this, STATECHANGE_REMOTE_IDLE, m_state.GetRemoteRecursiveOperation());
 	m_state.RegisterHandler(this, STATECHANGE_LOCAL_RECURSION_LISTING);
@@ -798,27 +796,20 @@ void CSearchDialog::Run()
 
 	ShowModal();
 
+	Stop();
+
 	SaveConditions();
 
 	m_state.UnregisterHandler(this, STATECHANGE_LOCAL_RECURSION_STATUS);
 	m_state.UnregisterHandler(this, STATECHANGE_LOCAL_RECURSION_LISTING);
 	m_state.UnregisterHandler(this, STATECHANGE_REMOTE_IDLE);
 	m_state.UnregisterHandler(this, STATECHANGE_REMOTE_DIR_OTHER);
-
-	if (searched_remote_) {
-		if (!m_state.IsRemoteIdle()) {
-			m_state.m_pCommandQueue->Cancel();
-			m_state.GetRemoteRecursiveOperation()->StopRecursiveOperation();
-		}
-		if (!m_original_dir.empty()) {
-			m_state.ChangeRemoteDir(m_original_dir);
-		}
-	}
 }
 
 void CSearchDialog::OnStateChange(t_statechange_notifications notification, std::wstring const&, const void* data2)
 {
 	if (!searching_) {
+		SetCtrlState();
 		return;
 	}
 
@@ -844,6 +835,7 @@ void CSearchDialog::OnStateChange(t_statechange_notifications notification, std:
 				if (!m_state.IsLocalIdle()) {
 					return;
 				}
+				m_pComparisonManager->CompareListings();
 			}
 		}
 		searching_ = false;
@@ -1078,8 +1070,6 @@ void CSearchDialog::OnSearch(wxCommandEvent&)
 		}
 
 		m_remote_search_root = path;
-
-		searched_remote_ = true;
 	}
 
 	searching_ = true;
@@ -1136,7 +1126,7 @@ void CSearchDialog::OnSearch(wxCommandEvent&)
 		root.add_dir_to_visit_restricted(m_remote_search_root, std::wstring(), true);
 		m_state.GetRemoteRecursiveOperation()->AddRecursionRoot(std::move(root));
 		ActiveFilters const filters; // Empty, recurse into everything
-		m_state.GetRemoteRecursiveOperation()->StartRecursiveOperation(CRecursiveOperation::recursive_list, filters, m_remote_search_root);
+		m_state.GetRemoteRecursiveOperation()->StartRecursiveOperation(CRecursiveOperation::recursive_list, filters);
 	}
 
 	SetCtrlState();
@@ -1168,7 +1158,14 @@ void CSearchDialog::Stop()
 
 void CSearchDialog::SetCtrlState()
 {
-	xrc_call(*this, "ID_START", &wxButton::Enable, !searching_);
+	bool can_start = !searching_;
+	if (mode_ != search_mode::local && !m_state.IsRemoteIdle()) {
+		can_start = false;
+	}
+	if (mode_ != search_mode::remote && !m_state.IsLocalIdle()) {
+		can_start = false;
+	}
+	xrc_call(*this, "ID_START", &wxButton::Enable, can_start);
 	xrc_call(*this, "ID_STOP", &wxButton::Enable, searching_);
 	xrc_call(*this, "ID_LOCAL_SEARCH", &wxRadioButton::Enable, !searching_);
 	xrc_call(*this, "ID_REMOTE_SEARCH", &wxRadioButton::Enable, !searching_ && m_state.IsRemoteConnected());
@@ -1316,8 +1313,9 @@ void CSearchTransferDialog::OnBrowse(wxCommandEvent&)
 	}
 
 	wxDirDialog dlg(this, _("Select target download directory"), pText->GetValue(), wxDD_NEW_DIR_BUTTON);
-	if (dlg.ShowModal() == wxID_OK)
+	if (dlg.ShowModal() == wxID_OK) {
 		pText->ChangeValue(dlg.GetPath());
+	}
 }
 
 void CSearchTransferDialog::OnOK(wxCommandEvent&)
@@ -1501,7 +1499,7 @@ void CSearchDialog::OnDownload(wxCommandEvent&)
 		m_state.GetRemoteRecursiveOperation()->AddRecursionRoot(std::move(root));
 	}
 	ActiveFilters const filters; // Empty, recurse into everything
-	m_state.GetRemoteRecursiveOperation()->StartRecursiveOperation(mode, filters, m_original_dir, start);
+	m_state.GetRemoteRecursiveOperation()->StartRecursiveOperation(mode, filters, start);
 }
 
 void CSearchDialog::OnUpload(wxCommandEvent&)
@@ -1693,7 +1691,12 @@ void CSearchDialog::OnDeleteRemote(wxCommandEvent&)
 		m_state.m_pCommandQueue->ProcessCommand(new CDeleteCommand(entry.path, std::move(files_to_delete)));
 	}
 
+	bool deleting_current{};
 	for (auto path : selected_dirs) {
+		if (path.IsParentOf(m_state.GetRemotePath(), false, true)) {
+			deleting_current = true;
+		}
+
 		std::wstring segment;
 		if (path.HasParent()) {
 			segment = path.GetLastSegment();
@@ -1703,8 +1706,13 @@ void CSearchDialog::OnDeleteRemote(wxCommandEvent&)
 		root.add_dir_to_visit(path, segment);
 		m_state.GetRemoteRecursiveOperation()->AddRecursionRoot(std::move(root));
 	}
+
+	if (deleting_current) {
+		m_state.ChangeRemoteDir(m_remote_search_root);
+	}
+
 	ActiveFilters const filters; // Empty, recurse into everything
-	m_state.GetRemoteRecursiveOperation()->StartRecursiveOperation(CRecursiveOperation::recursive_delete, filters, m_original_dir);
+	m_state.GetRemoteRecursiveOperation()->StartRecursiveOperation(CRecursiveOperation::recursive_delete, filters);
 }
 
 void CSearchDialog::OnDeleteLocal(wxCommandEvent&)
@@ -1824,7 +1832,7 @@ void CSearchDialog::SaveConditions()
 	file.Save(true);
 }
 
-void CSearchDialog::OnChangeSearchMode(wxCommandEvent& ev)
+void CSearchDialog::OnChangeSearchMode(wxCommandEvent&)
 {
 	wxString const strPath = xrc_call(*this, "ID_PATH", &wxTextCtrl::GetValue);
 
