@@ -12,7 +12,7 @@
 #include <functional>
 #include <list>
 
-struct build
+struct build final
 {
 	std::wstring url_;
 	std::wstring version_;
@@ -20,7 +20,13 @@ struct build
 	int64_t size_{-1};
 };
 
-struct version_information
+enum class resource_type : int
+{
+	update_dialog,
+	overlay
+};
+
+struct version_information final
 {
 	bool empty() const {
 		return available_.version_.empty() && !eol_;
@@ -36,7 +42,7 @@ struct version_information
 
 	std::wstring changelog_;
 
-	std::wstring resources_;
+	std::map<resource_type, std::wstring> resources_;
 
 	bool eol_{};
 };
@@ -60,7 +66,7 @@ public:
 };
 
 class CFileZillaEngineContext;
-class CUpdater final : public wxEvtHandler, private EngineNotificationHandler
+class CUpdater final : public wxEvtHandler
 {
 public:
 	CUpdater(CUpdateHandler& parent, CFileZillaEngineContext& engine_context, std::function<void(CActiveNotification const&)> const& activityNotificationHandler);
@@ -75,7 +81,7 @@ public:
 	UpdaterState GetState() const { return state_; }
 	build AvailableBuild() const { return version_information_.available_; }
 	std::wstring GetChangelog() const { return version_information_.changelog_; }
-	std::wstring GetResources() const { return version_information_.resources_; }
+	std::wstring GetResources(resource_type t) const;
 
 	std::wstring DownloadedFile() const;
 
@@ -120,8 +126,7 @@ protected:
 
 	void SetState(UpdaterState s);
 
-	virtual void OnEngineEvent(CFileZillaEngine* engine);
-	void DoOnEngineEvent(CFileZillaEngine* engine);
+	void OnEngineEvent(CFileZillaEngine* engine);
 
 	DECLARE_EVENT_TABLE()
 	void OnTimer(wxTimerEvent& ev);
